import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

class ElevarmAlert extends StatelessWidget {
  /// The alert variant.
  final ElevarmAlertVariant variant;

  /// The alert text.
  final String text;

  /// The Callback when close alert
  final VoidCallback? onClose;

  const ElevarmAlert({
    super.key,
    required this.text,
    required this.variant,
    this.onClose,
  });

  @override
  Widget build(BuildContext context) {
    String? assetNameIcon;
    Color? iconColor;
    Color? backgroundColor;
    Color? borderColor;
    Color? textColor;

    if (variant == ElevarmAlertVariant.danger) {
      assetNameIcon =
          'packages/elevarm_ui/assets/elevarm_icons/outline/alerts-feedback/alert-triangle.svg';
      iconColor = ElevarmColors.danger600;
      backgroundColor = ElevarmColors.danger100;
      borderColor = ElevarmColors.danger200;
      textColor = ElevarmColors.danger600;
    } else if (variant == ElevarmAlertVariant.success) {
      assetNameIcon =
          'packages/elevarm_ui/assets/elevarm_icons/outline/general/check-circle.svg';
      iconColor = ElevarmColors.success600;
      backgroundColor = ElevarmColors.success100;
      borderColor = ElevarmColors.success200;
      textColor = ElevarmColors.success600;
    } else {
      assetNameIcon =
          'packages/elevarm_ui/assets/elevarm_icons/outline/general/info-circle.svg';
      iconColor = ElevarmColors.info600;
      backgroundColor = ElevarmColors.info100;
      borderColor = ElevarmColors.info200;
      textColor = ElevarmColors.info600;
    }

    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(
          ElevarmBorderRadius.sm,
        ),
        border: Border.all(
          color: borderColor,
        ),
        color: backgroundColor,
      ),
      child: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            ElevarmIcon(
              assetNameIcon,
              color: iconColor,
            ),
            const SizedBox(width: 12.0),
            Expanded(
              child: Text(
                text,
                style: ElevarmFontFamilies.inter(
                  fontSize: ElevarmFontSizes.sm,
                  fontWeight: ElevarmFontWeights.regular,
                  color: textColor,
                ),
              ),
            ),
            if (onClose != null)
              InkWell(
                onTap: onClose,
                child: ElevarmIcon(
                  'packages/elevarm_ui/assets/elevarm_icons/outline/general/x-close.svg',
                  color: iconColor,
                ),
              ),
          ],
        ),
      ),
    );
  }
}
