import 'dart:math';

import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:elevarm_ui/src/utils/utils.dart';
import 'package:flutter/material.dart';
import 'package:timeago/timeago.dart' as timeago;

class ElevarmFileUploadCard extends StatelessWidget {
  /// The file name.
  final String filename;

  /// The file size.
  final int fileSize;

  // Whether to format file size to decimal or binary.
  final bool inBinaryFileSize;

  /// The upload time.
  final DateTime uploadedAt;

  /// Whether to show progress indicator.
  final bool showProgressIndicator;

  /// File upload progresss from 0 to 1.
  final double uploadProgress;

  /// Callback when delete button is pressed.
  final VoidCallback? onDelete;

  /// Callback when download button is pressed.
  final VoidCallback? onDownload;

  const ElevarmFileUploadCard({
    super.key,
    required this.filename,
    required this.fileSize,
    required this.uploadedAt,
    this.inBinaryFileSize = false,
    this.uploadProgress = 1.0,
    this.showProgressIndicator = false,
    this.onDelete,
    this.onDownload,
  });

  @override
  Widget build(BuildContext context) {
    /// Set local time to format date uploadAt
    timeago.setLocaleMessages('id_short', timeago.IdMessages());

    return Container(
      decoration: BoxDecoration(
        border: Border.all(
          color: ElevarmColors.grey200,
        ),
        borderRadius: BorderRadius.circular(ElevarmBorderRadius.md),
      ),
      padding: const EdgeInsets.all(16.0),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            width: 36.0,
            height: 36.0,
            decoration: const BoxDecoration(
              shape: BoxShape.circle,
              color: ElevarmColors.primary100,
            ),
            child: const Center(
              child: ElevarmIcon(
                'packages/elevarm_ui/assets/elevarm_icons/outline/images/image-01.svg',
                color: ElevarmColors.primary,
              ),
            ),
          ),
          const SizedBox(width: 16.0),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    Expanded(
                      child: Text(filename,
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: ElevarmFontFamilies.inter(
                            color: ElevarmColors.neutral,
                            fontSize: ElevarmFontSizes.sm,
                            fontWeight: ElevarmFontWeights.semibold,
                          )),
                    ),
                    const SizedBox(width: 8.0),
                    onDelete != null
                        ? ElevarmLinkNeutralButton.iconOnly(
                            iconAssetName:
                                'packages/elevarm_ui/assets/elevarm_icons/outline/general/trash-01.svg',
                            onPressed: onDelete,
                          )
                        : Container(),
                    onDownload != null
                        ? ElevarmLinkNeutralButton.iconOnly(
                            iconAssetName:
                                'packages/elevarm_ui/assets/elevarm_icons/outline/general/download-02.svg',
                            onPressed: onDownload,
                          )
                        : Container(),
                  ],
                ),
                const SizedBox(height: 2.0),
                Text(
                    '${StringUtils.getFileSize(fileSize, inBinaryFileSize)} - diunggah ${timeago.format(uploadedAt, locale: 'id_short')}',
                    style: ElevarmFontFamilies.inter(
                      color: ElevarmColors.neutral300,
                      fontSize: ElevarmFontSizes.xs,
                      fontWeight: ElevarmFontWeights.regular,
                    )),
                const SizedBox(height: 2.0),
                showProgressIndicator
                    ? Row(
                        children: [
                          Expanded(
                            child: ElevarmLinearProgressIndicator(
                              value: uploadProgress,
                            ),
                          ),
                          const SizedBox(width: 12.0),
                          Text('${(uploadProgress * 100).toStringAsFixed(1)}%',
                              style: ElevarmFontFamilies.inter(
                                color: ElevarmColors.grey700,
                                fontSize: ElevarmFontSizes.sm,
                                fontWeight: ElevarmFontWeights.medium,
                              )),
                        ],
                      )
                    : Container(),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
